השקת שדרוג של ארגונים ב-gdcloud

שם

השקת שדרוג של ארגונים ב-gdcloud – הפעלת שדרוג לגרסה חדשה עבור הארגונים שצוינו.

SYNOPSIS

gdcloud organizations upgrade rollout --version=VERSION --names=ORG_NAME1,ORG_NAME2,... --zone=ZONE_NAME [flags]

דוגמאות


To upgrade the infra organization "root" to version "1.14.3-gdch.1000-1", run:

    gdcloud organization upgrade rollout --version=1.14.3-gdch.1000-1 --names=root

To upgrade an organizations "org-1" and "org-2" to version "1.14.3-gdch.1000-1", run:

    gdcloud organization upgrade rollout --version=1.14.3-gdch.1000-1 --names=org-1,org-2,... --zone=zone1

To upgrade all eligible organizations in zone1 to version "1.14.3-gdch.1000-1", run:

    gdcloud organization upgrade rollout --version=1.14.3-gdch.1000-1 --all --zone=zone1

Root organization must be at the new version or greater, before a version is available to any other organizations in a zone.

דגלים אופציונליים

  -a, --all                         Upgrade all organizations in the given zone.
      --direct                      Rollout OC changes to the specified organization(s) directly.
      --distribute-artifacts        Distribute artifacts to a tenant org before rolling out to the org directly.
      --ignore-maintenance-window   Ignore maintenance window for tenant organization upgrade.
  -n, --names strings               Comma-separated list of organizations to trigger upgrade for.
      --skip-checks                 Skip preflight and postflight checks for organization upgrade.
      --version string              Version to upgrade to.
  -z, --zone string                 Zone to rollout upgrade for.

GDCLOUD WIDE FLAGS

הדגלים האלה זמינים לכל הפקודות: --configuration, ‏ --format, ‏ --help, ‏ --project, ‏ --quiet.

מידע נוסף זמין בדף סקירה כללית של מדריך העזר ל-CLI של gcloud.